==> jc-1.4.0.tar.gz: gnu/java/nio/SelectorProviderImpl.h <==
// public class gnu.java.nio.SelectorProviderImpl

// class file dependencies
// @dep_class 6925f211bbaec1da gnu_java_nio_SelectorProviderImpl
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7a7cc23db1b62549 java_nio_channels_spi_SelectorProvider

// header file dependencies
// @dep_header java_nio_channels_spi_SelectorProvider

#include "java/nio/channels/spi/SelectorProvider.h"

#ifndef _JC_gnu_java_nio_SelectorProviderImpl_H_
#define _JC_gnu_java_nio_SelectorProviderImpl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_DatagramChannel$object;
struct _jc_java_nio_channels_Pipe$object;
struct _jc_java_nio_channels_ServerSocketChannel$object;
struct _jc_java_nio_channels_SocketChannel$object;
struct _jc_java_nio_channels_spi_AbstractSelector$object;

// Typedefs
typedef struct _jc_gnu_java_nio_SelectorProviderImpl$sub_refs	_jc_gnu_java_nio_SelectorProviderImpl$sub_refs;
typedef struct _jc_gnu_java_nio_SelectorProviderImpl$sub_nonrefs	_jc_gnu_java_nio_SelectorProviderImpl$sub_nonrefs;
typedef struct _jc_gnu_java_nio_SelectorProviderImpl$refs	_jc_gnu_java_nio_SelectorProviderImpl$refs;
typedef struct _jc_gnu_java_nio_SelectorProviderImpl$nonrefs	_jc_gnu_java_nio_SelectorProviderImpl$nonrefs;
typedef struct _jc_gnu_java_nio_SelectorProviderImpl$object	_jc_gnu_java_nio_SelectorProviderImpl$object;

typedef const struct _jc_gnu_java_nio_SelectorProviderImpl$vmethods	_jc_gnu_java_nio_SelectorProviderImpl$vmethods;
typedef const struct _jc_gnu_java_nio_SelectorProviderImpl$vtable	_jc_gnu_java_nio_SelectorProviderImpl$vtable;
typedef const struct _jc_gnu_java_nio_SelectorProviderImpl$vtype	_jc_gnu_java_nio_SelectorProviderImpl$vtype;

// Constructors
extern void _jc_gnu_java_nio_SelectorProviderImpl$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_nio_SelectorProviderImpl$object *);

// Virtual methods
extern struct _jc_java_nio_channels_DatagramChannel$object *_jc_gnu_java_nio_SelectorProviderImpl$method$openDatagramChannel$ab5cdc178ebfdf11(_jc_env *, struct _jc_gnu_java_nio_SelectorProviderImpl$object *);
extern struct _jc_java_nio_channels_Pipe$object *_jc_gnu_java_nio_SelectorProviderImpl$method$openPipe$a14c1306bc23b331(_jc_env *, struct _jc_gnu_java_nio_SelectorProviderImpl$object *);
extern struct _jc_java_nio_channels_spi_AbstractSelector$object *_jc_gnu_java_nio_SelectorProviderImpl$method$openSelector$bb7aeaf99dc269ad(_jc_env *, struct _jc_gnu_java_nio_SelectorProviderImpl$object *);
extern struct _jc_java_nio_channels_ServerSocketChannel$object *_jc_gnu_java_nio_SelectorProviderImpl$method$openServerSocketChannel$c5bb130c60378b57(_jc_env *, struct _jc_gnu_java_nio_SelectorProviderImpl$object *);
extern struct _jc_java_nio_channels_SocketChannel$object *_jc_gnu_java_nio_SelectorProviderImpl$method$openSocketChannel$24c1128adb909d51(_jc_env *, struct _jc_gnu_java_nio_SelectorProviderImpl$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_SelectorProviderImpl$method_info$openDatagramChannel$ab5cdc178ebfdf11;
extern _jc_method _jc_gnu_java_nio_SelectorProviderImpl$method_info$openPipe$a14c1306bc23b331;
extern _jc_method _jc_gnu_java_nio_SelectorProviderImpl$method_info$openSelector$bb7aeaf99dc269ad;
extern _jc_method _jc_gnu_java_nio_SelectorProviderImpl$method_info$openServerSocketChannel$c5bb130c60378b57;
extern _jc_method _jc_gnu_java_nio_SelectorProviderImpl$method_info$openSocketChannel$24c1128adb909d51;

// Virtual methods structure
struct _jc_gnu_java_nio_SelectorProviderImpl$vmethods {
	struct _jc_java_nio_channels_DatagramChannel$object	*(*openDatagramChannel$ab5cdc178ebfdf11)(_jc_env *, struct _jc_gnu_java_nio_SelectorProviderImpl$object *);
	struct _jc_java_nio_channels_Pipe$object	*(*openPipe$a14c1306bc23b331)(_jc_env *, struct _jc_gnu_java_nio_SelectorProviderImpl$object *);
	struct _jc_java_nio_channels_spi_AbstractSelector$object	*(*openSelector$bb7aeaf99dc269ad)(_jc_env *, struct _jc_gnu_java_nio_SelectorProviderImpl$object *);
	struct _jc_java_nio_channels_ServerSocketChannel$object	*(*openServerSocketChannel$c5bb130c60378b57)(_jc_env *, struct _jc_gnu_java_nio_SelectorProviderImpl$object *);
	struct _jc_java_nio_channels_SocketChannel$object	*(*openSocketChannel$24c1128adb909d51)(_jc_env *, struct _jc_gnu_java_nio_SelectorProviderImpl$object *);
};

// Vtable
struct _jc_gnu_java_nio_SelectorProviderImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_spi_SelectorProvider$vmethods	java_nio_channels_spi_SelectorProvider;
	_jc_gnu_java_nio_SelectorProviderImpl$vmethods	gnu_java_nio_SelectorProviderImpl;
};

// Vtype
struct _jc_gnu_java_nio_SelectorProviderImpl$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_SelectorProviderImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_SelectorProviderImpl$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_SelectorProviderImpl$refs {
    _jc_gnu_java_nio_SelectorProviderImpl$sub_refs	gnu_java_nio_SelectorProviderImpl;
    _jc_java_nio_channels_spi_SelectorProvider$sub_refs	java_nio_channels_spi_SelectorProvider;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_SelectorProviderImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_SelectorProviderImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_spi_SelectorProvider$sub_nonrefs	java_nio_channels_spi_SelectorProvider;
    _jc_gnu_java_nio_SelectorProviderImpl$sub_nonrefs	gnu_java_nio_SelectorProviderImpl;
};

// Object instance structure
struct _jc_gnu_java_nio_SelectorProviderImpl$object {
	_jc_gnu_java_nio_SelectorProviderImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_SelectorProviderImpl$vtype	*vtype;
	_jc_gnu_java_nio_SelectorProviderImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_SelectorProviderImpl$vtype _jc_gnu_java_nio_SelectorProviderImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_SelectorProviderImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_SelectorProviderImpl$class_object;

#endif	/* _JC_gnu_java_nio_SelectorProviderImpl_H_ */

==> jc-1.4.6.tar.gz: gnu/java/nio/SelectorProviderImpl.h <==
// public class gnu.java.nio.SelectorProviderImpl

// class file dependencies
// @dep_class 6925f211bbaec1da gnu_java_nio_SelectorProviderImpl
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7a7cc23db1b62549 java_nio_channels_spi_SelectorProvider

// header file dependencies
// @dep_header java_nio_channels_spi_SelectorProvider

#include "java/nio/channels/spi/SelectorProvider.h"

#ifndef _JC_gnu_java_nio_SelectorProviderImpl_H_
#define _JC_gnu_java_nio_SelectorProviderImpl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_DatagramChannel$object;
struct _jc_java_nio_channels_Pipe$object;
struct _jc_java_nio_channels_ServerSocketChannel$object;
struct _jc_java_nio_channels_SocketChannel$object;
struct _jc_java_nio_channels_spi_AbstractSelector$object;

// Typedefs
typedef struct _jc_gnu_java_nio_SelectorProviderImpl$sub_refs	_jc_gnu_java_nio_SelectorProviderImpl$sub_refs;
typedef struct _jc_gnu_java_nio_SelectorProviderImpl$sub_nonrefs	_jc_gnu_java_nio_SelectorProviderImpl$sub_nonrefs;
typedef struct _jc_gnu_java_nio_SelectorProviderImpl$refs	_jc_gnu_java_nio_SelectorProviderImpl$refs;
typedef struct _jc_gnu_java_nio_SelectorProviderImpl$nonrefs	_jc_gnu_java_nio_SelectorProviderImpl$nonrefs;
typedef struct _jc_gnu_java_nio_SelectorProviderImpl$object	_jc_gnu_java_nio_SelectorProviderImpl$object;

typedef const struct _jc_gnu_java_nio_SelectorProviderImpl$vmethods	_jc_gnu_java_nio_SelectorProviderImpl$vmethods;
typedef const struct _jc_gnu_java_nio_SelectorProviderImpl$vtable	_jc_gnu_java_nio_SelectorProviderImpl$vtable;
typedef const struct _jc_gnu_java_nio_SelectorProviderImpl$vtype	_jc_gnu_java_nio_SelectorProviderImpl$vtype;

// Constructors
extern void _jc_gnu_java_nio_SelectorProviderImpl$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_nio_SelectorProviderImpl$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_nio_channels_DatagramChannel$object *_jc_gnu_java_nio_SelectorProviderImpl$method$openDatagramChannel$ab5cdc178ebfdf11(_jc_env *, struct _jc_gnu_java_nio_SelectorProviderImpl$object *) _JC_JCNI_ATTR;
extern struct _jc_java_nio_channels_Pipe$object *_jc_gnu_java_nio_SelectorProviderImpl$method$openPipe$a14c1306bc23b331(_jc_env *, struct _jc_gnu_java_nio_SelectorProviderImpl$object *) _JC_JCNI_ATTR;
extern struct _jc_java_nio_channels_spi_AbstractSelector$object *_jc_gnu_java_nio_SelectorProviderImpl$method$openSelector$bb7aeaf99dc269ad(_jc_env *, struct _jc_gnu_java_nio_SelectorProviderImpl$object *) _JC_JCNI_ATTR;
extern struct _jc_java_nio_channels_ServerSocketChannel$object *_jc_gnu_java_nio_SelectorProviderImpl$method$openServerSocketChannel$c5bb130c60378b57(_jc_env *, struct _jc_gnu_java_nio_SelectorProviderImpl$object *) _JC_JCNI_ATTR;
extern struct _jc_java_nio_channels_SocketChannel$object *_jc_gnu_java_nio_SelectorProviderImpl$method$openSocketChannel$24c1128adb909d51(_jc_env *, struct _jc_gnu_java_nio_SelectorProviderImpl$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_SelectorProviderImpl$method_info$openDatagramChannel$ab5cdc178ebfdf11;
extern _jc_method _jc_gnu_java_nio_SelectorProviderImpl$method_info$openPipe$a14c1306bc23b331;
extern _jc_method _jc_gnu_java_nio_SelectorProviderImpl$method_info$openSelector$bb7aeaf99dc269ad;
extern _jc_method _jc_gnu_java_nio_SelectorProviderImpl$method_info$openServerSocketChannel$c5bb130c60378b57;
extern _jc_method _jc_gnu_java_nio_SelectorProviderImpl$method_info$openSocketChannel$24c1128adb909d51;

// Virtual methods structure
struct _jc_gnu_java_nio_SelectorProviderImpl$vmethods {
	struct _jc_java_nio_channels_DatagramChannel$object	*(*openDatagramChannel$ab5cdc178ebfdf11)(_jc_env *, struct _jc_gnu_java_nio_SelectorProviderImpl$object *) _JC_JCNI_ATTR;
	struct _jc_java_nio_channels_Pipe$object	*(*openPipe$a14c1306bc23b331)(_jc_env *, struct _jc_gnu_java_nio_SelectorProviderImpl$object *) _JC_JCNI_ATTR;
	struct _jc_java_nio_channels_spi_AbstractSelector$object	*(*openSelector$bb7aeaf99dc269ad)(_jc_env *, struct _jc_gnu_java_nio_SelectorProviderImpl$object *) _JC_JCNI_ATTR;
	struct _jc_java_nio_channels_ServerSocketChannel$object	*(*openServerSocketChannel$c5bb130c60378b57)(_jc_env *, struct _jc_gnu_java_nio_SelectorProviderImpl$object *) _JC_JCNI_ATTR;
	struct _jc_java_nio_channels_SocketChannel$object	*(*openSocketChannel$24c1128adb909d51)(_jc_env *, struct _jc_gnu_java_nio_SelectorProviderImpl$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_nio_SelectorProviderImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_spi_SelectorProvider$vmethods	java_nio_channels_spi_SelectorProvider;
	_jc_gnu_java_nio_SelectorProviderImpl$vmethods	gnu_java_nio_SelectorProviderImpl;
};

// Vtype
struct _jc_gnu_java_nio_SelectorProviderImpl$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_SelectorProviderImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_SelectorProviderImpl$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_SelectorProviderImpl$refs {
    _jc_gnu_java_nio_SelectorProviderImpl$sub_refs	gnu_java_nio_SelectorProviderImpl;
    _jc_java_nio_channels_spi_SelectorProvider$sub_refs	java_nio_channels_spi_SelectorProvider;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_SelectorProviderImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_SelectorProviderImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_spi_SelectorProvider$sub_nonrefs	java_nio_channels_spi_SelectorProvider;
    _jc_gnu_java_nio_SelectorProviderImpl$sub_nonrefs	gnu_java_nio_SelectorProviderImpl;
};

// Object instance structure
struct _jc_gnu_java_nio_SelectorProviderImpl$object {
	_jc_gnu_java_nio_SelectorProviderImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_SelectorProviderImpl$vtype	*vtype;
	_jc_gnu_java_nio_SelectorProviderImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_SelectorProviderImpl$vtype _jc_gnu_java_nio_SelectorProviderImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_SelectorProviderImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_SelectorProviderImpl$class_object;

#endif	/* _JC_gnu_java_nio_SelectorProviderImpl_H_ */
